@@ -193,9 +193,9 @@ shishi_cfg (Shishi * handle, char *option)
 	  handle->realminfos = xrealloc (handle->realminfos,
 					 (handle->nrealminfos + 1) *
 					 sizeof (*handle->realminfos));
+	  memset (&handle->realminfos[handle->nrealminfos], 0,
+		  sizeof (handle->realminfos[handle->nrealminfos]));
 	  handle->realminfos[handle->nrealminfos].name = realm;
-	  handle->realminfos[handle->nrealminfos].kdcaddresses = NULL;
-	  handle->realminfos[handle->nrealminfos].nkdcaddresses = 0;
 	  handle->nrealminfos++;
 	  break;
 
@@ -451,24 +451,46 @@ shishi_cfg_print (Shishi * handle, FILE * fh)
  * shishi_cfg_default_systemfile:
  * @handle: Shishi library handle create by shishi_init().
  *
- * Return value: Return system configuration filename.
+ * The system configuration file name is decided at compile-time, but
+ * may be overridden by the environment variable SHISHI_CONFIG.
+ *
+ * Return value: Return system configuration file name.
  **/
 const char *
 shishi_cfg_default_systemfile (Shishi * handle)
 {
+  char *file;
+
+  file = getenv ("SHISHI_CONFIG");
+  if (file)
+    return file;
+
   return SYSTEMCFGFILE;
 }
 
+#define BASE_DIR "/.shishi"
+
 /**
  * shishi_cfg_default_userdirectory:
  * @handle: Shishi library handle create by shishi_init().
  *
+ * The default user directory (used for, e.g. Shishi ticket cache) is
+ * normally computed by appending BASE_DIR ("/.shishi") to the content
+ * of the environment variable $HOME, but can be overridden by
+ * specifying the complete path in the environment variable
+ * SHISHI_HOME.
+ *
  * Return value: Return directory with configuration files etc.
  **/
 const char *
 shishi_cfg_default_userdirectory (Shishi * handle)
 {
   char *home;
+  char *envdir;
+
+  envdir = getenv ("SHISHI_HOME");
+  if (envdir)
+    return envdir;
 
   if (!handle->userdirectory)
     {
@@ -499,6 +521,8 @@ shishi_cfg_userdirectory_file (Shishi * handle, const char *file)
   return out;
 }
 
+#define USERCFG_FILE "shishi.conf"
+
 /**
  * shishi_cfg_default_userfile:
  * @handle: Shishi library handle create by shishi_init().
@@ -508,14 +532,8 @@ shishi_cfg_userdirectory_file (Shishi * handle, const char *file)
 const char *
 shishi_cfg_default_userfile (Shishi * handle)
 {
-  char *home;
-
   if (!handle->usercfgfile)
-    {
-      home = getenv ("HOME");
-
-      asprintf (&handle->usercfgfile, "%s%s", home ? home : "", USERCFG_FILE);
-    }
+    handle->usercfgfile = shishi_cfg_userdirectory_file (handle, USERCFG_FILE);
 
   return handle->usercfgfile;
 }
