@@ -1,5 +1,5 @@
 /* crypto-rc4.c --- draft-brezak-win2k-krb-rc4-hmac-04 crypto functions.
- * Copyright (C) 2003  Simon Josefsson
+ * Copyright (C) 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -127,7 +127,7 @@ arcfour_hmac_encrypt (Shishi * handle,
   else
     offset = 10;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("k1pt");
       _shishi_hexprint (L40 + offset, 14 - offset);
@@ -139,7 +139,7 @@ arcfour_hmac_encrypt (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("k1");
       _shishi_hexprint (K1, 16);
@@ -149,7 +149,7 @@ arcfour_hmac_encrypt (Shishi * handle,
   if (export)
     memset (K1 + 7, 0xAB, 9);
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("k1");
       _shishi_hexprint (K1, 16);
@@ -180,7 +180,7 @@ arcfour_hmac_encrypt (Shishi * handle,
     goto done;
   memcpy (pt + 8, in, inlen);
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("random");
       _shishi_hexprint (pt, 8);
@@ -190,7 +190,7 @@ arcfour_hmac_encrypt (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("cksum");
       _shishi_hexprint (cksum, 16);
@@ -200,7 +200,7 @@ arcfour_hmac_encrypt (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("k3");
       _shishi_hexprint (K3, 16);
@@ -210,7 +210,7 @@ arcfour_hmac_encrypt (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("ct");
       _shishi_hexprint (ct, ptlen);
@@ -270,7 +270,7 @@ arcfour_hmac_decrypt (Shishi * handle,
   else
     offset = 10;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("k1pt");
       _shishi_hexprint (L40 + offset, 14 - offset);
@@ -282,7 +282,7 @@ arcfour_hmac_decrypt (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("k1");
       _shishi_hexprint (K1, 16);
@@ -292,7 +292,7 @@ arcfour_hmac_decrypt (Shishi * handle,
   if (export)
     memset (K1 + 7, 0xAB, 9);
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("k1");
       _shishi_hexprint (K1, 16);
@@ -304,7 +304,7 @@ arcfour_hmac_decrypt (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("k3");
       _shishi_hexprint (K3, 16);
@@ -315,7 +315,7 @@ arcfour_hmac_decrypt (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("cksum pt");
       _shishi_hexprint (pt, inlen - 16);
@@ -325,7 +325,7 @@ arcfour_hmac_decrypt (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("cksum");
       _shishi_hexprint (cksum, 16);
@@ -417,7 +417,7 @@ arcfour_hmac_md5_checksum (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("Ksign");
       _shishi_hexprint (Ksign, 16);
@@ -428,7 +428,7 @@ arcfour_hmac_md5_checksum (Shishi * handle,
   memcpy (pt, T, 4);
   memcpy (pt + 4, in, inlen);
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("pt");
       _shishi_hexprint (pt, ptlen);
@@ -438,7 +438,7 @@ arcfour_hmac_md5_checksum (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("md");
       _shishi_hexprint (tmp, 16);
@@ -449,7 +449,7 @@ arcfour_hmac_md5_checksum (Shishi * handle,
   if (err)
     goto done;
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       puts ("hmac");
       _shishi_hexprint (*out, 16);
@@ -466,16 +466,16 @@ done:
 
 static int
 arcfour_hmac_random_to_key (Shishi * handle,
-			    const char *random, size_t randomlen,
+			    const char *rnd, size_t rndlen,
 			    Shishi_key * outkey)
 {
-  if (randomlen != shishi_key_length (outkey))
+  if (rndlen != shishi_key_length (outkey))
     {
       shishi_error_printf (handle, "ARCFOUR random to key caller error");
       return SHISHI_CRYPTO_ERROR;
     }
 
-  shishi_key_value_set (outkey, random);
+  shishi_key_value_set (outkey, rnd);
 
   return SHISHI_OK;
 }
