@@ -43,7 +43,7 @@ _shishi_kdcreq (Shishi * handle, int as)
   int res;
   Shishi_asn1 node;
   const char *servicebuf[3];
-  char noncebuf[4];
+  uint32_t nonce;
 
   if (as)
     node = shishi_asn1_asreq (handle);
@@ -108,9 +108,9 @@ _shishi_kdcreq (Shishi * handle, int as)
   if (res != SHISHI_OK)
     goto error;
 
-  shishi_randomize (handle, 0, &noncebuf[0], sizeof (noncebuf));
-  res = shishi_asn1_write (handle, node, "req-body.nonce", noncebuf,
-			   sizeof (noncebuf));
+  shishi_randomize (handle, 0, &nonce, sizeof (nonce));
+  nonce &= 0x7FFFFFFF; /* XXX fix _libtasn1_convert_integer. */
+  res = shishi_kdcreq_nonce_set (handle, node, nonce);
   if (res != SHISHI_OK)
     goto error;
 
@@ -342,6 +342,30 @@ shishi_kdcreq_nonce (Shishi * handle, Shishi_asn1 kdcreq, uint32_t * nonce)
   return SHISHI_OK;
 }
 
+/**
+ * shishi_kdcreq_nonce_set:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @kdcreq: KDC-REQ variable to set client name field in.
+ * @nonce: integer nonce to store in KDC-REQ.
+ *
+ * Store nonce number field in KDC-REQ.
+ *
+ * Return value: Returns %SHISHI_OK iff successful.
+ **/
+int
+shishi_kdcreq_nonce_set (Shishi * handle,
+			 Shishi_asn1 kdcreq,
+			 uint32_t nonce)
+{
+  int res;
+
+  res = shishi_asn1_write_uint32 (handle, kdcreq, "req-body.nonce", nonce);
+  if (res != SHISHI_OK)
+    return res;
+
+  return SHISHI_OK;
+}
+
 /**
  * shishi_kdcreq_set_cname:
  * @handle: shishi handle as allocated by shishi_init().
@@ -566,6 +590,62 @@ shishi_kdcreq_set_realmserver (Shishi * handle,
   return SHISHI_OK;
 }
 
+/**
+ * shishi_kdcreq_till:
+ * @handle: Shishi library handle create by shishi_init().
+ * @kdcreq: KDC-REQ variable to get client name from.
+ * @till: pointer to newly allocated zero terminated string containing
+ *   "till" field with generalized time.  May be %NULL (to only
+ *   populate @realmlen).
+ * @tilllen: pointer to length of @till on output, excluding
+ *   terminating zero.  May be %NULL (to only populate @tilllen).
+ *
+ * Get "till" field (i.e. "endtime") in KDC-REQ, as zero-terminated
+ * string.  The string is typically 15 characters long.  The string is
+ * allocate by this function, and it is the responsibility of the
+ * caller to deallocate it.  Note that the output length @realmlen
+ * does not include the terminating zero.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
+int
+shishi_kdcreq_till (Shishi * handle, Shishi_asn1 kdcreq,
+		    char **till, size_t * tilllen)
+{
+  return shishi_asn1_read2 (handle, kdcreq, "req-body.till",
+			    till, tilllen);
+}
+
+/**
+ * shishi_kdcreq_tillc:
+ * @handle: Shishi library handle create by shishi_init().
+ * @tkt: input variable with ticket info.
+ *
+ * Extract C time corresponding to the "till" field.
+ *
+ * Return value: Returns C time interpretation of the "till" field in
+ * KDC-REQ.
+ **/
+time_t
+shishi_kdcreq_tillc (Shishi * handle, Shishi_asn1 kdcreq)
+{
+  char *till;
+  size_t tilllen;
+  time_t t = (time_t) -1;
+  int res;
+
+  res = shishi_kdcreq_till (handle, kdcreq, &till, &tilllen);
+  if (res != SHISHI_OK)
+    return t;
+
+  if (tilllen == GENERALIZEDTIME_TIME_LEN + 1) /* XXX why +1 ? */
+    t = shishi_generalize_ctime (handle, till);
+
+  free (till);
+
+  return t;
+}
+
 /**
  * shishi_kdcreq_etype:
  * @handle: shishi handle as allocated by shishi_init().
