@@ -1,5 +1,5 @@
 /* krberror.c --- Functions related to KRB-ERROR packet.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -129,7 +129,7 @@ shishi_krberror_save (Shishi * handle, FILE * fh, Shishi_asn1 krberror)
  **/
 int
 shishi_krberror_to_file (Shishi * handle, Shishi_asn1 krberror,
-			 int filetype, char *filename)
+			 int filetype, const char *filename)
 {
   FILE *fh;
   int res;
@@ -209,7 +209,7 @@ shishi_krberror_read (Shishi * handle, FILE * fh, Shishi_asn1 * krberror)
  **/
 int
 shishi_krberror_from_file (Shishi * handle, Shishi_asn1 * krberror,
-			   int filetype, char *filename)
+			   int filetype, const char *filename)
 {
   int res;
   FILE *fh;
@@ -255,18 +255,18 @@ shishi_krberror_from_file (Shishi * handle, Shishi_asn1 * krberror,
 int
 shishi_krberror_build (Shishi * handle, Shishi_asn1 krberror)
 {
-  char *time;
-  size_t tmplen = sizeof (time);
+  char *t;
+  size_t tmplen = sizeof (t);
   char *tmp;
   int32_t errc;
-  int usec;
+  uint32_t usec;
   int rc;
 
-  rc = shishi_krberror_ctime (handle, krberror, &time);
+  rc = shishi_krberror_ctime (handle, krberror, &t);
   if (rc != SHISHI_OK &&
       rc != SHISHI_ASN1_NO_ELEMENT && rc != SHISHI_ASN1_NO_VALUE)
     return rc;
-  free (time);
+  free (t);
   if (rc == SHISHI_ASN1_NO_VALUE)
     {
       rc = shishi_krberror_remove_ctime (handle, krberror);
@@ -298,8 +298,8 @@ shishi_krberror_build (Shishi * handle, Shishi_asn1 krberror)
 	return rc;
     }
 
-  tmplen = sizeof (time);
-  rc = shishi_krberror_cname (handle, krberror, time, &tmplen);
+  tmplen = sizeof (t);
+  rc = shishi_krberror_cname (handle, krberror, t, &tmplen);
   if (rc != SHISHI_OK &&
       rc != SHISHI_ASN1_NO_ELEMENT && rc != SHISHI_ASN1_NO_VALUE)
     return rc;
@@ -322,8 +322,8 @@ shishi_krberror_build (Shishi * handle, Shishi_asn1 krberror)
 	return rc;
     }
 
-  tmplen = sizeof (time);
-  rc = shishi_krberror_sname (handle, krberror, time, &tmplen);
+  tmplen = sizeof (t);
+  rc = shishi_krberror_sname (handle, krberror, t, &tmplen);
   if (rc != SHISHI_OK && rc != SHISHI_ASN1_NO_VALUE)
     return rc;
   if (rc == SHISHI_ASN1_NO_VALUE || tmplen == 0)
@@ -712,23 +712,23 @@ shishi_krberror_server_set (Shishi * handle,
  * shishi_krberror_ctime:
  * @handle: shishi handle as allocated by shishi_init().
  * @krberror: Krberror to set client name field in.
- * @ctime: newly allocated zero-terminated output array with client time.
+ * @t: newly allocated zero-terminated output array with client time.
  *
  * Extract client time from KRB-ERROR.
  *
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_ctime (Shishi * handle, Shishi_asn1 krberror, char **ctime)
+shishi_krberror_ctime (Shishi * handle, Shishi_asn1 krberror, char **t)
 {
-  return shishi_time (handle, krberror, "ctime", ctime);
+  return shishi_time (handle, krberror, "ctime", t);
 }
 
 /**
  * shishi_krberror_ctime_set:
  * @handle: shishi handle as allocated by shishi_init().
  * @krberror: Krberror as allocated by shishi_krberror().
- * @ctime: string with generalized time value to store in Krberror.
+ * @t: string with generalized time value to store in Krberror.
  *
  * Store client time in Krberror.
  *
@@ -736,13 +736,14 @@ shishi_krberror_ctime (Shishi * handle, Shishi_asn1 krberror, char **ctime)
  **/
 int
 shishi_krberror_ctime_set (Shishi * handle,
-			   Shishi_asn1 krberror, const char *ctime)
+			   Shishi_asn1 krberror,
+			   const char *t)
 {
   int res;
 
-  if (ctime)
+  if (t)
     res = shishi_asn1_write (handle, krberror, "ctime",
-			     ctime, GENERALIZEDTIME_TIME_LEN);
+			     t, GENERALIZEDTIME_TIME_LEN);
   else
     res = shishi_asn1_write (handle, krberror, "ctime", NULL, 0);
   if (res != SHISHI_OK)
@@ -783,7 +784,7 @@ shishi_krberror_remove_ctime (Shishi * handle, Shishi_asn1 krberror)
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_cusec (Shishi * handle, Shishi_asn1 krberror, int *cusec)
+shishi_krberror_cusec (Shishi * handle, Shishi_asn1 krberror, uint32_t *cusec)
 {
   int res;
 
@@ -805,7 +806,9 @@ shishi_krberror_cusec (Shishi * handle, Shishi_asn1 krberror, int *cusec)
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_cusec_set (Shishi * handle, Shishi_asn1 krberror, int cusec)
+shishi_krberror_cusec_set (Shishi * handle,
+			   Shishi_asn1 krberror,
+			   uint32_t cusec)
 {
   int res;
 
@@ -841,23 +844,23 @@ shishi_krberror_remove_cusec (Shishi * handle, Shishi_asn1 krberror)
  * shishi_krberror_stime:
  * @handle: shishi handle as allocated by shishi_init().
  * @krberror: Krberror to set client name field in.
- * @stime: newly allocated zero-terminated output array with server time.
+ * @t: newly allocated zero-terminated output array with server time.
  *
  * Extract server time from KRB-ERROR.
  *
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_stime (Shishi * handle, Shishi_asn1 krberror, char **stime)
+shishi_krberror_stime (Shishi * handle, Shishi_asn1 krberror, char **t)
 {
-  return shishi_time (handle, krberror, "stime", stime);
+  return shishi_time (handle, krberror, "stime", t);
 }
 
 /**
  * shishi_krberror_stime_set:
  * @handle: shishi handle as allocated by shishi_init().
  * @krberror: Krberror as allocated by shishi_krberror().
- * @stime: string with generalized time value to store in Krberror.
+ * @t: string with generalized time value to store in Krberror.
  *
  * Store server time in Krberror.
  *
@@ -865,12 +868,12 @@ shishi_krberror_stime (Shishi * handle, Shishi_asn1 krberror, char **stime)
  **/
 int
 shishi_krberror_stime_set (Shishi * handle,
-			   Shishi_asn1 krberror, const char *stime)
+			   Shishi_asn1 krberror, const char *t)
 {
   int res;
 
   res = shishi_asn1_write (handle, krberror, "stime",
-			   stime, GENERALIZEDTIME_TIME_LEN);
+			   t, GENERALIZEDTIME_TIME_LEN);
   if (res != SHISHI_OK)
     return res;
 
@@ -888,7 +891,9 @@ shishi_krberror_stime_set (Shishi * handle,
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_susec (Shishi * handle, Shishi_asn1 krberror, int *susec)
+shishi_krberror_susec (Shishi * handle,
+		       Shishi_asn1 krberror,
+		       uint32_t *susec)
 {
   int res;
 
@@ -910,7 +915,9 @@ shishi_krberror_susec (Shishi * handle, Shishi_asn1 krberror, int *susec)
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_susec_set (Shishi * handle, Shishi_asn1 krberror, int susec)
+shishi_krberror_susec_set (Shishi * handle,
+			   Shishi_asn1 krberror,
+			   uint32_t susec)
 {
   int res;
 
