@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.15"
+#define SHISHI_VERSION "0.0.16"
 
 /* Error codes */
 typedef enum
@@ -611,8 +611,8 @@ extern const char *shishi_error (Shishi * handle);
 extern void shishi_error_clear (Shishi * handle);
 extern void shishi_error_set (Shishi * handle, const char *errstr);
 extern void shishi_error_printf (Shishi * handle, const char *format, ...);
-extern int shishi_outputtype (Shishi * handle);
-extern void shishi_set_outputtype (Shishi * handle, int type);
+extern int shishi_error_outputtype (Shishi * handle);
+extern void shishi_error_set_outputtype (Shishi * handle, int type);
 extern void shishi_info (Shishi * handle, const char *format, ...);
 extern void shishi_warn (Shishi * handle, const char *format, ...);
 
@@ -688,9 +688,6 @@ extern int shishi_ticket_set_enc_part (Shishi * handle, Shishi_asn1 ticket,
 extern int shishi_ticket_add_enc_part (Shishi * handle, Shishi_asn1 ticket,
 				       Shishi_key * key,
 				       Shishi_asn1 encticketpart);
-extern int shishi_enckdcreppart_key_set (Shishi * handle,
-					 Shishi_asn1 enckdcreppart,
-					 Shishi_key * key);
 extern int shishi_ticket_decrypt (Shishi * handle, Shishi_asn1 ticket,
 				  Shishi_key * key,
 				  Shishi_asn1 * encticketpart);
@@ -775,7 +772,7 @@ extern int shishi_tkt_transited_policy_checked_p (Shishi_tkt * tkt);
 extern int shishi_tkt_ok_as_delegate_p (Shishi_tkt * tkt);
 
 /* tkts.c */
-extern char *shishi_tkts_default_file_guess (void);
+extern char *shishi_tkts_default_file_guess (Shishi * handle);
 extern const char *shishi_tkts_default_file (Shishi * handle);
 extern void shishi_tkts_default_file_set (Shishi * handle,
 					  const char *tktsfile);
@@ -1055,6 +1052,9 @@ extern int shishi_asreq_cnamerealm_get (Shishi * handle, Shishi_asn1 kdcreq,
 					size_t * cnamerealmlen);
 extern int shishi_kdcreq_nonce (Shishi * handle, Shishi_asn1 kdcreq,
 				uint32_t * nonce);
+extern int shishi_kdcreq_nonce_set (Shishi * handle,
+				    Shishi_asn1 kdcreq,
+				    uint32_t nonce);
 extern int shishi_kdcreq_client (Shishi * handle, Shishi_asn1 kdcreq,
 				 char **client, size_t * clientlen);
 extern int shishi_kdcreq_cname_get (Shishi * handle,
@@ -1083,6 +1083,9 @@ extern int shishi_kdcreq_set_server (Shishi * handle, Shishi_asn1 req,
 				     const char *service);
 extern int shishi_kdcreq_set_realmserver (Shishi * handle, Shishi_asn1 req,
 					  char *realm, char *service);
+extern int shishi_kdcreq_till (Shishi * handle, Shishi_asn1 kdcreq,
+			       char **till, size_t * tilllen);
+extern time_t shishi_kdcreq_tillc (Shishi * handle, Shishi_asn1 kdcreq);
 extern int shishi_kdcreq_etype (Shishi * handle, Shishi_asn1 kdcreq,
 				int32_t * etype, int netype);
 extern int shishi_kdcreq_set_etype (Shishi * handle, Shishi_asn1 kdcreq,
@@ -1125,24 +1128,6 @@ extern int shishi_kdcreq_add_padata_tgs (Shishi * handle,
 					 Shishi_asn1 apreq);
 extern int shishi_kdcreq_build (Shishi * handle, Shishi_asn1 kdcreq);
 
-/* enckdcreppart.c */
-extern Shishi_asn1 shishi_enckdcreppart (Shishi * handle);
-extern Shishi_asn1 shishi_encasreppart (Shishi * handle);
-extern int shishi_enckdcreppart_srealmserver_set (Shishi * handle,
-						  Shishi_asn1 enckdcreppart,
-						  const char *srealm,
-						  const char *server);
-extern int shishi_enckdcreppart_nonce_set (Shishi * handle,
-					   Shishi_asn1 enckdcreppart,
-					   uint32_t nonce);
-extern int
-shishi_enckdcreppart_populate_encticketpart (Shishi * handle,
-					     Shishi_asn1 enckdcreppart,
-					     Shishi_asn1 encticketpart);
-extern int shishi_enckdcreppart_flags_set (Shishi * handle,
-					   Shishi_asn1 enckdcreppart,
-					   int flags);
-
 /* kdc.c */
 extern int shishi_as_derive_salt (Shishi * handle,
 				  Shishi_asn1 asreq,
@@ -1224,6 +1209,47 @@ extern int shishi_kdcrep_crealmserver_set (Shishi * handle,
 extern int shishi_kdcrep_set_enc_part (Shishi * handle, Shishi_asn1 kdcrep,
 				       int etype, int kvno,
 				       const char *buf, size_t buflen);
+extern int shishi_kdcrep_decrypt (Shishi * handle,
+				  Shishi_asn1 kdcrep,
+				  Shishi_key * key,
+				  int keyusage, Shishi_asn1 * enckdcreppart);
+
+/* enckdcreppart.c */
+extern Shishi_asn1 shishi_enckdcreppart (Shishi * handle);
+extern Shishi_asn1 shishi_encasreppart (Shishi * handle);
+extern int shishi_enckdcreppart_get_key (Shishi * handle,
+					 Shishi_asn1 enckdcreppart,
+					 Shishi_key ** key);
+extern int shishi_enckdcreppart_key_set (Shishi * handle,
+					 Shishi_asn1 enckdcreppart,
+					 Shishi_key * key);
+extern int shishi_enckdcreppart_nonce_set (Shishi * handle,
+					   Shishi_asn1 enckdcreppart,
+					   uint32_t nonce);
+extern int shishi_enckdcreppart_flags_set (Shishi * handle,
+					   Shishi_asn1 enckdcreppart,
+					   int flags);
+extern int shishi_enckdcreppart_endtime_set (Shishi * handle,
+					     Shishi_asn1 enckdcreppart,
+					     const char *endtime);
+extern int shishi_enckdcreppart_srealm_set (Shishi * handle,
+					    Shishi_asn1 enckdcreppart,
+					    const char *srealm);
+extern int shishi_enckdcreppart_sname_set (Shishi * handle,
+					   Shishi_asn1 enckdcreppart,
+					   Shishi_name_type name_type,
+					   char *sname[]);
+extern int shishi_enckdcreppart_server_set (Shishi * handle,
+					    Shishi_asn1 enckdcreppart,
+					    const char *server);
+extern int shishi_enckdcreppart_srealmserver_set (Shishi * handle,
+						  Shishi_asn1 enckdcreppart,
+						  const char *srealm,
+						  const char *server);
+extern int
+shishi_enckdcreppart_populate_encticketpart (Shishi * handle,
+					     Shishi_asn1 enckdcreppart,
+					     Shishi_asn1 encticketpart);
 
 /* krberror.c */
 extern Shishi_asn1 shishi_krberror (Shishi * handle);
@@ -1891,26 +1917,6 @@ extern int shishi_apreq_decrypt (Shishi * handle, Shishi_asn1 apreq,
 				 Shishi_key * key, int keyusage,
 				 Shishi_asn1 * authenticator);
 
-/* kdcrep.c */
-extern int shishi_kdcrep_decrypt (Shishi * handle,
-				  Shishi_asn1 kdcrep,
-				  Shishi_key * key,
-				  int keyusage, Shishi_asn1 * enckdcreppart);
-/* enckdcreppart.c */
-extern int shishi_enckdcreppart_get_key (Shishi * handle,
-					 Shishi_asn1 enckdcreppart,
-					 Shishi_key ** key);
-extern int shishi_enckdcreppart_srealm_set (Shishi * handle,
-					    Shishi_asn1 enckdcreppart,
-					    const char *srealm);
-extern int shishi_enckdcreppart_sname_set (Shishi * handle,
-					   Shishi_asn1 enckdcreppart,
-					   Shishi_name_type name_type,
-					   char *sname[]);
-extern int shishi_enckdcreppart_server_set (Shishi * handle,
-					    Shishi_asn1 enckdcreppart,
-					    const char *server);
-
 /* aprep.c */
 extern Shishi_asn1 shishi_aprep (Shishi * handle);
 extern int shishi_aprep_print (Shishi * handle, FILE * fh, Shishi_asn1 aprep);
